%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?pyver: %global pyver %(%{__python} -c "import sys ; print sys.version[:3]")}

%global modname fedmsg

Name:           fedmsg
Version:        0.6.0
Release:        1%{?dist}
Summary:        Tools for Fedora Infrastructure real-time messaging
Group:          Applications/Internet
License:        LGPLv2+
URL:            http://github.com/ralphbean/fedmsg
Source0:        http://pypi.python.org/packages/source/f/%{modname}/%{modname}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python-devel
BuildRequires:  python-setuptools-devel
BuildRequires:  python-moksha-hub >= 1.0.2
BuildRequires:  python-bunch
BuildRequires:  python-nose
BuildRequires:  python-daemon
BuildRequires:  python-requests
BuildRequires:  m2crypto
BuildRequires:  python-m2ext
BuildRequires:  python-pygments
BuildRequires:  python-fabulous

Requires:       python-moksha-hub >= 1.0.1
Requires:       python-simplejson
Requires:       python-zmq
Requires:       python-daemon
Requires:       python-requests
Requires:       m2crypto
Requires:       python-m2ext
Requires:       python-pygments
Requires:       python-fabulous

%if 0%{?rhel} <= 6
BuildRequires:  python-ordereddict
BuildRequires:  python-argparse
Requires:       python-ordereddict
Requires:       python-argparse
%endif

%description
Python API used around Fedora Infrastructure to send and receive messages with
zeromq.  Includes some CLI tools.

%package announce
Summary: The fedmsg-announce command
Group: Applications/Internet
Requires: %{name} = %{version}-%{release}

%description announce
This package contains the fedmsg-announce command for sending announcements.

%package collectd
Summary: A fedmsg plugin for collectd
Group: Applications/Internet
Requires: %{name} = %{version}-%{release}

%description collectd
This package contains the fedmsg-collectd command which produces output
suitable for consumption by a collectd plugin.

%package hub
Summary: The FedMsg Hub
Group: Applications/Internet
Requires: %{name} = %{version}-%{release}

%description hub
This package contains configuration and init scripts for the FedMsg hub.

%package relay
Summary: The FedMsg Relay
Group: Applications/Internet
Requires: %{name} = %{version}-%{release}

%description relay
This package contains configuration and init scripts for the FedMsg relay.

%package irc
Summary: The FedMsg IRC Bot
Group: Applications/Internet
Requires: %{name} = %{version}-%{release}

%description irc
This package contains configuration and init scripts for the FedMsg IRC bot.

%package tweet
Summary: The FedMsg Twitter/StatusNet Bot
Group: Applications/Internet
Requires: %{name} = %{version}-%{release}

%description tweet
This package contains configuration and init scripts for the FedMsg
Twitter/StatusNet bot.

%package gateway
Summary: The FedMsg Gateway daemon.
Group: Applications/Internet
Requires: %{name} = %{version}-%{release}

%description gateway
This package contains configuration and init scripts for the FedMsg IRC bot.
It will rebroadcast messages from the bus to a specially designated ZMQ pub
socket.  Useful for repeating messages outside a firewal.

%prep
%setup -q -n %{modname}-%{version}

%build
%{__python} setup.py build

# Create this temporary symlink that's only needed for the test suite.
ln -s fedmsg/tests/test_certs dev_certs

# Unfortunately, neither of these tests will run on koji since they require
# some network connectivity.  With a note of sadness, we destroy them.
rm fedmsg/tests/test_hub.py
rm fedmsg/tests/test_threads.py

%check
%if 0%{?rhel} <= 6
# Check section removed until a RHEL6 bug with python-repoze-what-plugins-sql
# can be fixed.  It causes a fatal error in the test suite.
# https://bugzilla.redhat.com/show_bug.cgi?id=813925
%else
PYTHONPATH=$(pwd) python setup.py test
%endif

%install
%{__python} setup.py install -O1 --skip-build \
    --install-data=%{_datadir} --root %{buildroot}

%{__mkdir_p} %{buildroot}%{_sysconfdir}/fedmsg.d/
%{__cp} fedmsg.d/*.py %{buildroot}%{_sysconfdir}/fedmsg.d/.

%{__mkdir_p} %{buildroot}/%{_var}/run/%{modname}
%{__mkdir_p} %{buildroot}/%{_var}/log/%{modname}

%{__mkdir_p} %{buildroot}%{_sysconfdir}/init.d
%{__install} init.d/fedmsg-hub.init %{buildroot}%{_sysconfdir}/init.d/fedmsg-hub
%{__install} init.d/fedmsg-relay.init %{buildroot}%{_sysconfdir}/init.d/fedmsg-relay
%{__install} init.d/fedmsg-irc.init %{buildroot}%{_sysconfdir}/init.d/fedmsg-irc
# XXX - fedmsg-tweet.ini is a typo.  It will be moved to fedmsg-tweet.init in
# the next version (0.6.1)
%{__install} init.d/fedmsg-tweet.ini %{buildroot}%{_sysconfdir}/init.d/fedmsg-tweet
%{__install} init.d/fedmsg-gateway.init %{buildroot}%{_sysconfdir}/init.d/fedmsg-gateway

# Logrotate configuration
%{__mkdir_p} %{buildroot}/%{_sysconfdir}/logrotate.d
%{__install} logrotate %{buildroot}/%{_sysconfdir}/logrotate.d/%{modname}


%pre
%{_sbindir}/groupadd -r %{modname} &>/dev/null || :
%{_sbindir}/useradd  -r -s /sbin/nologin -d %{_datadir}/%{modname} -M \
                     -c 'FedMsg' -g %{modname} %{modname} &>/dev/null || :


%post hub
/sbin/chkconfig --add fedmsg-hub

%post relay
/sbin/chkconfig --add fedmsg-relay

%post irc
/sbin/chkconfig --add fedmsg-irc

%post tweet
/sbin/chkconfig --add fedmsg-tweet

%post gateway
/sbin/chkconfig --add fedmsg-gateway


%preun hub
if [ $1 -eq 0 ]; then
    /sbin/service fedmsg-hub stop >/dev/null 2>&1
    /sbin/chkconfig --del fedmsg-hub
fi

%preun relay
if [ $1 -eq 0 ]; then
    /sbin/service fedmsg-relay stop >/dev/null 2>&1
    /sbin/chkconfig --del fedmsg-relay
fi

%preun irc
if [ $1 -eq 0 ]; then
    /sbin/service fedmsg-irc stop >/dev/null 2>&1
    /sbin/chkconfig --del fedmsg-irc
fi

%preun tweet
if [ $1 -eq 0 ]; then
    /sbin/service fedmsg-tweet stop >/dev/null 2>&1
    /sbin/chkconfig --del fedmsg-tweet
fi

%preun gateway
if [ $1 -eq 0 ]; then
    /sbin/service fedmsg-gateway stop >/dev/null 2>&1
    /sbin/chkconfig --del fedmsg-gateway
fi

%files
%doc doc/ README.rst LICENSE
%{_bindir}/fedmsg-logger
%{_bindir}/fedmsg-tail
%{_bindir}/fedmsg-config
%{_bindir}/fedmsg-collectd

%attr(755, %{modname}, %{modname}) %dir %{_var}/log/%{modname}
%attr(755, %{modname}, %{modname}) %dir %{_var}/run/%{modname}

%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}-py%{pyver}.egg-info/

%config(noreplace) %{_sysconfdir}/fedmsg.d
%config(noreplace) %{_sysconfdir}/logrotate.d/%{modname}

%files announce
%{_bindir}/fedmsg-announce

%files collectd
%{_bindir}/fedmsg-collectd

%files hub
%{_bindir}/fedmsg-hub
%{_sysconfdir}/init.d/fedmsg-hub

%files relay
%{_bindir}/fedmsg-relay
%{_sysconfdir}/init.d/fedmsg-relay

%files irc
%{_bindir}/fedmsg-irc
%{_sysconfdir}/init.d/fedmsg-irc

%files tweet
%{_bindir}/fedmsg-tweet
%{_sysconfdir}/init.d/fedmsg-tweet

%files gateway
%{_bindir}/fedmsg-gateway
%{_sysconfdir}/init.d/fedmsg-gateway

%changelog
* Thu Nov 15 2012 Ralph Bean <rbean@redhat.com> - 0.6.0-1
- New upstream version.
- New service and subpackage: fedmsg-tweet.
- New command and subpackage: fedmsg-announce.
- New command and subpackage: fedmsg-collectd.
- New routing_policy config and extension of fedmsg.crypto.
- New functions in fedmsg.text to extract usernames and packages for a msg.
- Updated docs
- Pull in logrotate configuration from upstream.
- Updated rhel conditionals.
- Remove old temporary BR on orbited

* Wed Nov 14 2012 Ralph Bean <rbean@redhat.com> - 0.5.6-2
- Added a logrotate configuration.

* Thu Oct 25 2012 Ralph Bean <rbean@redhat.com> - 0.5.6-1
- More fedmsg.text enhancements.
- New fedmsg-collectd command.
- Reenabled test_text.py

* Tue Oct 23 2012 Ralph Bean <rbean@redhat.com> - 0.5.5-1
- Lots of work on enhancing and simplifying fedmsg.text from Luke Macken.
- Remove test_text.py since it now depends on test_hub.py

* Tue Oct 09 2012 Ralph Bean <rbean@redhat.com> - 0.5.4-4
- Disable those few tests that require network connectivity for koji.

* Tue Oct 09 2012 Ralph Bean <rbean@redhat.com> - 0.5.4-3
- BuildRequires on python-pygments.

* Tue Oct 09 2012 Ralph Bean <rbean@redhat.com> - 0.5.4-2
- BuildRequires on python-pygments.

* Mon Oct 08 2012 Ralph Bean <rbean@redhat.com> - 0.5.4-1
- New mediawiki, tagger, and git icons in fedmsg.text.
- Create symlink of dev_certs in build section so tests can pass.
- Re-enable the test suite in %%check again.
- fedmsg.text entries for tagger rank changes.
- Updated default FI endpoints (for staging).
- Remove full text from mediawiki messages to reduce spam.
- Recursively merge dicts in /etc/fedmsg.d/

* Fri Oct 05 2012 Ralph Bean <rbean@redhat.com> - 0.5.3-1
- Icons and fedmsg.text support for fedmsg-notify
- Re-disabled the tests to get a quick release out for fedmsg-notify.

* Thu Oct 04 2012 Luke Macken <lmacken@redhat.com> - 0.5.2-2
- Re-enable the test suite in %%check which got accidently removed.

* Wed Oct 03 2012 Ralph Bean <rbean@redhat.com> - 0.5.2-1
- Allow timeout when connecting to a non-existant fedmsg-relay
- fedmsg.text entries for new lookaside messages
- fedmsg.text groundwork support for icons
- Enhancements to the docs
- Fixed regression in fedmsg-irc

* Thu Sep 27 2012 Ralph Bean <rbean@redhat.com> - 0.5.1-1
- Fixed links in meetbot reprs
- fedmsg.text entries for pkgdb2branch and releng
- unicode bugfix for fedmsg-tail --terse
- Fix bug alongside python-moksha-hub-1.0.3-1
- New defaults fedora-infrastructure endpoints
- Improved docs
- Links to real diffs for mediawiki messages
- Specifiable and longer default tcp timeout for fedmsg-irc
- Improved config parsing for fedmsg-irc
- Bugfix to git-hook; ignore pushed tags instead of crashing
- Allow inner context to be destroyed and recreated inside a thread

* Thu Sep 27 2012 Ralph Bean <rbean@redhat.com> - 0.5.0-2
- Require python-pygments.

* Wed Sep 19 2012 Ralph Bean <rbean@redhat.com> - 0.5.0-1
- Depend on new Moksha
- Massive docs improvement.
- Minor API simplification.
- Suppress some annoying warnings from fedmsg-tail.

* Fri Aug 31 2012 Ralph Bean <rbean@redhat.com> - 0.4.0-1
- Bugfix to fedmsg.encoding.

* Fri Aug 31 2012 Ralph Bean <rbean@redhat.com> - 0.3.9-1
- Bugfix to fedmsg-gateway.
- to_json utility for sqlalchemy.
- More convenient default config for end users.

* Thu Aug 23 2012 Ralph Bean <rbean@redhat.com> - 0.3.8-1
- fedmsg-gateway command, new!
- Improved thread cleanup with weakref.
- --terse option for fedmsg-tail
- Meetbot text processing support.
- Update to consumer API.. systematized enablement.

* Fri Aug 17 2012 Ralph Bean <rbean@redhat.com> - 0.3.6-1
- Expanded reprs.  Support for fedoratagger-0.2.2-1 messages.
- Unicode bugfix.

* Tue Aug 14 2012 Ralph Bean <rbean@redhat.com> - 0.3.5-1
- IRC colors
- fedmsg2repr updates (Luke Macken)
- Removed fedmsg-status and the heartbeat producer

* Mon Aug 13 2012 Ralph Bean <rbean@redhat.com> - 0.3.4-1
- Threadsafety bugfixes to fedmsg-tail
- New fedmsg.text items from Luke Macken.

* Sun Aug 12 2012 Ralph Bean <rbean@redhat.com> - 0.3.3-1
- thread safety (for bodhi masher)

* Wed Aug 08 2012 Ralph Bean <rbean@redhat.com> - 0.3.2-1
- msg2repr updates for scm.

* Wed Aug 08 2012 Ralph Bean <rbean@redhat.com> - 0.3.1-1
- msg2repr updates
- fedmsg-logger grepping.

* Tue Aug 07 2012 Ralph Bean <rbean@redhat.com> - 0.3.0-1
- Bugfix to fedmsg.text.

* Tue Aug 07 2012 Ralph Bean <rbean@redhat.com> - 0.2.9-1
- Upstream update including nicer message for fedmsg-irc.
- fedmsg.text.msg2repr

* Mon Aug 06 2012 Ralph Bean <rbean@redhat.com> - 0.2.7-4
- Remove unnecessary %%ghost on /var/run/fedmsg.

* Mon Aug 06 2012 Ralph Bean <rbean@redhat.com> - 0.2.7-3
- Hopefully fix to creation of /var/run/fedmsg.

* Mon Aug 06 2012 Ralph Bean <rbean@redhat.com> - 0.2.7-2
- Added a forgotten new requirement on python-requests.

* Sun Aug 05 2012 Ralph Bean <rbean@redhat.com> - 0.2.7-1
- Upstream bugfix to -logger and enhancement to -irc.

* Mon Jul 30 2012 Ralph Bean <rbean@redhat.com> - 0.2.6-2
- Require moksha >= 0.8.8

* Mon Jul 30 2012 Ralph Bean <rbean@redhat.com> - 0.2.6-1
- Upstream bugfixes and API enhancements.

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Jul 15 2012 Ralph Bean <rbean@redhat.com> - 0.2.5-1
- Upstream crypto updates in preparation for a more realistic X509 setup.

* Fri Jul 13 2012 Ralph Bean <rbean@redhat.com> - 0.2.4-1
- Upstream bugfix for when ssl is disabled.

* Wed Jul 11 2012 Ralph Bean <rbean@redhat.com> - 0.2.3-1
- Upstream bump that fixes some typos.

* Tue Jul 10 2012 Ralph Bean <rbean@redhat.com> - 0.2.2-3
- Added deps on python-argparse for py < 2.7 (rhel6)

* Sat Jul 07 2012 Ralph Bean <rbean@redhat.com> - 0.2.2-2
- Added deps on m2crypto and python-m2ext

* Sat Jul 07 2012 Ralph Bean <rbean@redhat.com> - 0.2.2-1
- Update to fedmsg-irc to fix lineRate issues
- fedmsg.crypto module - sign and validate messages

* Mon Jun 11 2012 Ralph Bean <rbean@redhat.com> - 0.2.1-2
- Require moksha >= 0.8.3

* Mon Jun 11 2012 Ralph Bean <rbean@redhat.com> - 0.2.1-1
- Override producers and consumers entry-points in the hub.  Should fix a
  collision that fedmsg-irc is having with fedoracommunity.

* Mon Jun 11 2012 Ralph Bean <rbean@redhat.com> - 0.2.0-4
- Introduce temporary hard dep on orbited.

* Mon Jun 11 2012 Ralph Bean <rbean@redhat.com> - 0.2.0-3
- /var/log/fedmsg wasn't being created correctly.

* Sat Jun 09 2012 Ralph Bean <rbean@redhat.com> - 0.2.0-2
- Split package into different daemonizable components.

* Thu Jun 07 2012 Ralph Bean <rbean@redhat.com> - 0.1.8-1
- Split config up into /etc/fedmsg.d/
- Removed tests.

* Wed Jun 06 2012 Ralph Bean <rbean@redhat.com> - 0.1.7-1
- Bugfix and tests.
- Added %%check section.

* Mon Jun 04 2012 Ralph Bean <rbean@redhat.com> - 0.1.6-1
- Support multiple endpoints per node-service.

* Tue May 29 2012 Ralph Bean <rbean@redhat.com> - 0.1.5-1
- Support multiple nodes-per-service.

* Fri May 25 2012 Ralph Bean <rbean@redhat.com> - 0.1.4-1
- Fresh version with removed shebang for packaging.
- %%define -> %%global
- Fixed end-of-line encodings in doc/conf.py

* Fri May 25 2012 Ralph Bean <rbean@redhat.com> - 0.1.3-2
- Renamed to just 'fedmsg' from python-fedmsg.

* Fri May 25 2012 Ralph Bean <rbean@redhat.com> - 0.1.3-1
- Integrating various pieces.  IRC bot fixes.
- Fixed a few specfile typos.

* Fri May 25 2012 Ralph Bean <rbean@redhat.com> - 0.1.2-1
- Version bump.

* Wed May 02 2012 Ralph Bean <rbean@redhat.com> - 0.1.1-2
- Removed clean section
- Removed defattr in files section
- Removed unnecessary references to buildroot

* Thu Apr 26 2012 Ralph Bean <rbean@redhat.com> - 0.1.1-1
- Support for busmon websocket options.

* Sat Apr 14 2012 Ralph Bean <rbean@redhat.com> - 0.1.0-1
- Initial packaging.
